﻿* Encoding: UTF-8.
* This syntax produces output required for MICS Statistical Snapshot IYCF, page 2 chart: Liquids or foods consumed by infants 0-5 months old.
cd "C:\MICS".
* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = 'ch.sav'.

weight by chweight.

select if (UF17 = 1 and cage < 6).

compute solidSemiSoft = any(1, BD8A, BD8B, BD8C, BD8D, BD8E, BD8F, BD8G, BD8H, BD8I, BD8J, BD8K, BD8L, BD8M, BD8N, BD8X).
variable labels solidSemiSoft "Receiving any solid, semi-solid or soft foods".

compute bf = 0.
if (BD3=1 & not any(1, BD7A, BD7B, BD7C, BD7D, BD7E, BD7X) & not solidSemiSoft) bf = 1.
if (BD3 = 1 & BD7A = 1 & not any(1, BD7B, BD7C, BD7D, BD7E, BD7X) & not solidSemiSoft)  bf = 2.
if (BD3=1 & any(1, BD7B, BD7C, BD7X) & not any(1, BD7D, BD7E) & not solidSemiSoft) bf = 3.
if (BD3=1 & any(1, BD7D, BD7E) & not solidSemiSoft) bf = 4.
if (BD3 = 1 & solidSemiSoft) bf = 5.
if (BD2 <> 1 or BD3 <> 1) bf = 6.

variable labels bf "Infant feeding pattern".
value labels bf 
  6 "No breastmilk [4]"
  5 "Breastmilk and complementary foods [3]"
  4 "Breastmilk and other milk / formula [2]"
  3 "Breastmilk and non-milk liquids [1]"
  2 "Breastmilk and plain water"
  1 "Breastmilk only".

compute cage2 = trunc(cage/2).
variable labels cage2 "Age".
value labels cage2 
  0 "0-1"
  1 "2-3"
  2 "4-5"
 .

compute total = 1.
value labels total 1 "Number of children".

compute tot2 = 100.
variable labels tot2 "Total".
value labels tot2 100 "".

* For labels in French uncomment commands below.

* variable labels bf "Type d'alimentation".
* value labels bf 
  6 "Non allaités"
  5 "Allaités au sein et aliments complémentaires"
  4 "Allaitement maternel et autre lait / préparation pour nourrissons"
  3 "Allaitement maternel et liquides non lactés"
  2 "Allaitement maternel et eau simple uniquement "
  1 "Allaitement maternel exclusif".
* value labels total 1 "Nombre d'enfants".
						
* ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = total display = none
  /table cage2 [c] by 
                 bf[c][rowpct.validn,'',f5.1] + tot2[s][mean,'',f5.1] + total[c][count,'',f5.0] 
  /slabels position = column visable = no
  /categories var = all empty = exclude missing = exclude
  /titles title=
	  "Table NU.A1. MICS Statistical Snapshot IYCF: Liquids or foods consumed by infants 0-5 months old" 
	  "Percent of infants aged 0-5 months receiving breastmilk only, breastmilk and plain water, breastmilk "
                    "and non-milk liquids, breastmilk and other milk/formula, breastmilk and complementary foods and no breastmilk, " + surveyname
           caption=
"[1] May also have been fed plain water"
"[2] May also have been fed plain water and/or non-milk liquids"
"[3] May also have been fed plain water, non-milk liquids and/or other milk/formula"
"[4] May have been fed plain water, non-milk liquids, other milk/infant formula and/or solid, semi-solid and soft foods".

* ctables command in French.
* ctables
  /vlabels variables = total display = none
  /table cage2 [c] by 
                bf[c][rowpct.validn,'',f5.1] + tot2[s][mean,'',f5.1] + total[c][count,'',f5.0] 
  /slabels position = column visable = no
  /categories var = all empty = exclude missing = exclude
  /titles title=
  	"Tableau NU.A1. Types d'alimentation infantile par âge" 
	  "Répartition en pourcentage des enfants âgés de 0-5 mois selon le type d'alimentation, " + surveyname.

new file.
